@@ -1,11 +1,9 @@
 package Date::Baha::i;
-BEGIN {
-  $Date::Baha::i::AUTHORITY = 'cpan:GENE';
-}
+our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert to and from Baha'i dates
 
-our $VERSION = '0.1903';
+our $VERSION = '0.2000';
 
 
 use strict;
@@ -254,7 +252,7 @@ sub as_string {
             $date_hash->{cycle_name},
             num2en_ordinal($date_hash->{kull_i_shay});
     }
-    elsif (!$args{size} && $args{numeric}) {
+    elsif (!$args{size} && $args{numeric} && !$args{alpha}) {
         # short numeric
         $date .= sprintf '%s/%s/%s', @$date_hash{qw(month day year)};
     }
@@ -468,15 +466,17 @@ Date::Baha::i - Convert to and from Baha'i dates
 
 =head1 VERSION
 
-version 0.1903
+version 0.2000
 
 =head1 SYNOPSIS
 
-  perl -MDate::Baha::i -le'print scalar from_bahai(epoch=>time)'
+  # perl -MDate::Baha::i -le'%d = to_bahai(); print as_string(\%d)'
 
   use Date::Baha'i;
 
-  $bahai_date = to_bahai();
+  my($year, $month, $day) = (2018, 10, 2);
+
+  my $bahai_date = to_bahai();
   $bahai_date = to_bahai(epoch => time);
   $bahai_date = to_bahai(
       year  => $year,
@@ -484,7 +484,7 @@ version 0.1903
       day   => $day,
   );
 
-  %bahai_date = to_bahai();
+  my %bahai_date = to_bahai();
   %bahai_date = to_bahai(epoch => time);
   %bahai_date = to_bahai(
       year  => $year,
@@ -492,7 +492,9 @@ version 0.1903
       day   => $day,
   );
 
-  $date = from_bahai(
+  my($bahai_year, $bahai_month, $bahai_day) = ('...', '...', '...');
+
+  my $date = from_bahai(
       year  => $bahai_year,
       month => $bahai_month,
       day   => $bahai_day,
@@ -507,17 +509,17 @@ version 0.1903
   $day = next_holy_day();
   $day = next_holy_day($year, $month, $day);
 
-  @cycles = cycles();
-  @years = years();
-  @months = months();
-  @days = days();
+  my @cycles = cycles();
+  my @years = years();
+  my @months = months();
+  my @days = days();
   @days = days_of_the_week();
-  %days = holy_days();
+  my %days = holy_days();
 
 =head1 DESCRIPTION
 
 This package renders the Baha'i date from two standard date formats -
-epoch time and a (year, month, day) triple.  It also converts a Baha'i 
+epoch time and a (year, month, day) triple.  It also converts a Baha'i
 date to standard ymd format.
 
 =head2 CYCLES
@@ -525,7 +527,7 @@ date to standard ymd format.
 Each cycle of nineteen years is called a Vahid.  Nineteen cycles constitute a
 period called Kull-i-Shay.
 
-The names of the years in each cycle are: 
+The names of the years in each cycle are:
 
   1.  Alif   - The Letter "A"
   2.  Ba     - The letter "B"
@@ -831,7 +833,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
